DecompositionType

Enum DecompositionType 

pub enum DecompositionType {
    None,
    Independent,
    Identity,
    Negation,
    And,
    Or,
    Le,
    Lt,
    Xor,
}
Basic boolean function families to describe decompositions

Variants



None

No valid decomposition with this variable



Independent

The function is independent of this variable



Identity

The function returns this variable



Negation

The function returns the negation of this variable



And

Decomposition possible as And



Or

Decomposition possible as Or



Le

Decomposition possible as Less-Or-Equal (equivalent to Nand for a top decomposition)



Lt

Decomposition possible as Less-Than (equivalent to Nor for a top decomposition)



Xor

Decomposition possible as Xor

Implementations

Source

impl DecompositionType

pub fn is_trivial(&self) -> bool

Returns whether the decomposition is trivial (independent, x or !x)

pub fn is_and_type(&self) -> bool

Returns whether the decomposition is based on an and gate or similar

pub fn is_xor_type(&self) -> bool

Returns whether the decomposition is based on a xor gate

pub fn is_simple_gate(&self) -> bool

Returns whether the decomposition is based on any 2-input gate